# diagrid listen

Stream an id's incoming requests to your terminal

### Description

Establish a local app connection from an id to your terminal. Receive all requests sent to the connected id without deploying application code.

```
diagrid listen [flags]
```

### Examples

```

  # Configure an id pub/sub subscriber to stream incoming messages to the terminal
  diagrid listen --id my-id --subscription 'my-subscription'

  # Configure an id to stream invocation requests made to a set list of app methods to the terminal
  diagrid listen --id my-id --invoke 'my-test-method-1,my-test-method-2'

  # Configure an id to stream input binding events received to the terminal
  diagrid listen --id my-id --binding 'my-input-binding-1'

```

### Options

```
  -a, --id string              id to connect to terminal
  -p, --project string         Name of existing project
      --subscription strings   Target pub/sub topic subscriptions on which to listen for messages
      --binding strings        Input binding triggers to listen for and stream to local terminal
      --invoke strings         One or more methods on which to listen for inbound invocation requests. Append '!' to the method name to return an error
      --raw                    Show raw request output for additional details
      --api-key string         Diagrid Cloud API key
  -h, --help                   help for listen
```
